==============
spade-artifact
==============


.. image:: https://img.shields.io/pypi/v/spade_artifact.svg
        :target: https://pypi.python.org/pypi/spade_artifact

.. image:: https://img.shields.io/travis/javipalanca/spade_artifact.svg
        :target: https://travis-ci.org/javipalanca/spade_artifact

.. image:: https://readthedocs.org/projects/spade-artifact/badge/?version=latest
        :target: https://spade-artifact.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Plugin for SPADE 3 to develop artifacts.


* Free software: MIT license
* Documentation: https://spade-artifact.readthedocs.io.


Features
--------

* Focus on observable properties (based on PubSub).
* Presence notifiaction support.
* Artifact class.
* ArtifactMixin for SPADE agents.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
